import NuRadioReco.detector.detector as detector

detector.buffer_db(in_memory=False, filename='arianna_detector_db.json')
